/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.connector.jdbc.xa;

import org.apache.flink.api.common.typeutils.SerializerTestBase;
import org.apache.flink.api.common.typeutils.TypeSerializer;

import javax.transaction.xa.Xid;

/** XaSerializersTest. */
class XidSerializersTest extends SerializerTestBase<Xid> {

    @Override
    protected TypeSerializer<Xid> createSerializer() {
        return new XidSerializer();
    }

    @Override
    protected int getLength() {
        return -1;
    }

    @Override
    protected Class<Xid> getTypeClass() {
        return Xid.class;
    }

    @Override
    protected Xid[] getTestData() {
        return new Xid[] {XaXidTest.XID};
    }
}
